.. :changelog:

History
=======

0.0.7 (2013-03-15)
------------------

- Rewrote the tmux calling code to be a little less verbose.

0.0.6 (2013-03-07)
------------------

- Properly handle sessions with a dot in it.

0.0.5 (2013-03-06)
------------------

- Added jsonschema to the requirements because I forgot it (thanks Andy McKay).
- Added missing comma in core.py

0.0.4 (2013-03-06)
------------------

- Added ``pytmux doctor`` command.

0.0.3 (2013-03-04)
------------------

- Edit has a default config that it will add if you are making a new file.

0.0.2 (2013-03-03)
------------------

- Run now has nicer error messages.

0.0.1 (2013-03-03)
------------------

- Initial release.
